@@ -1,9 +1,9 @@
 #ifndef WINPR_BUILD_FLAGS_H
 #define WINPR_BUILD_FLAGS_H
 
-#define WINPR_CFLAGS "-march=native -O2 -pipe -fvisibility=hidden -fno-omit-frame-pointer -Wredundant-decls -Wimplicit-function-declaration -fvisibility=hidden "
+#define WINPR_CFLAGS "-march=arrowlake -O2 -pipe -fvisibility=hidden -fno-omit-frame-pointer -Wredundant-decls -Wimplicit-function-declaration -fvisibility=hidden "
 #define WINPR_COMPILER_ID "Clang"
-#define WINPR_COMPILER_VERSION "20.1.7"
+#define WINPR_COMPILER_VERSION "20.1.8"
 #define WINPR_TARGET_ARCH "x64"
 #define WINPR_BUILD_CONFIG ""
 #define WINPR_BUILD_TYPE "RelWithDebInfo"
